Name changes
[privoxy.git] / project.h
index 263aae0..12eb23c 100644 (file)
--- a/project.h
+++ b/project.h
@@ -1,6 +1,6 @@
 #ifndef PROJECT_H_INCLUDED
 #define PROJECT_H_INCLUDED
-#define PROJECT_H_VERSION "$Id: project.h,v 1.57 2002/03/16 20:28:34 oes Exp $"
+#define PROJECT_H_VERSION "$Id: project.h,v 1.58 2002/03/24 13:25:43 swa Exp $"
 /*********************************************************************
  *
  * File        :  $Source: /cvsroot/ijbswa/current/project.h,v $
@@ -36,6 +36,9 @@
  *
  * Revisions   :
  *    $Log: project.h,v $
+ *    Revision 1.58  2002/03/24 13:25:43  swa
+ *    name change related issues
+ *
  *    Revision 1.57  2002/03/16 20:28:34  oes
  *    Added descriptions to the filters so users will know what they select in the cgi editor
  *
@@ -759,7 +762,7 @@ struct url_actions
 #define CSP_FLAG_TOGGLED_ON 0x20 /* Set if we are toggled on (FEATURE_TOGGLE) */
 
 /*
* The state of a JunkBuster processing thread.
  */
 struct client_state
 {
@@ -858,7 +861,7 @@ struct cgi_dispatcher
 
 
 /*
* A data file used by JunkBuster.  Kept in a linked list.
  */
 struct file_list
 {
@@ -1047,7 +1050,7 @@ struct configuration_spec
 #define SZ(X)  (sizeof(X) / sizeof(*X))
 
 #ifdef FEATURE_FORCE_LOAD
-#define FORCE_PREFIX "/IJB-FORCE-LOAD"
+#define FORCE_PREFIX "/PRIVOXY-FORCE"
 #endif /* def FEATURE_FORCE_LOAD */
 
 #ifdef FEATURE_NO_GIFS
@@ -1084,7 +1087,7 @@ struct configuration_spec
 /* HTTP snipplets */
 static const char CSUCCEED[] =
    "HTTP/1.0 200 Connection established\n"
-   "Proxy-Agent: IJ/" VERSION "\r\n\r\n";
+   "Proxy-Agent: Privoxy/" VERSION "\r\n\r\n";
 
 static const char CHEADER[] =
    "HTTP/1.0 400 Invalid header received from browser\r\n\r\n";
@@ -759,7 +762,7 @@ struct url_actions
 
 /*
- * The state of a JunkBuster processing thread.
+ * The state of a Privoxy processing thread.
  */
 struct client_state
@@ -858,7 +861,7 @@ struct cgi_dispatcher
 
 /*
- * A data file used by JunkBuster.  Kept in a linked list.
+ * A data file used by Privoxy.  Kept in a linked list.
  */
 struct file_list